Struct apistos_models::paths::Header
source · pub struct Header {
pub required: Option<bool>,
pub deprecated: Option<bool>,
pub description: Option<String>,
pub definition: Option<ParameterDefinition>,
pub style: Option<ParameterStyle>,
}Expand description
The Header Object follows the structure of the Parameter Object with the following changes:
nameMUST NOT be specified, it is given in the correspondingheadersmap.inMUST NOT be specified, it is implicitly in header.- All traits that are affected by the location MUST be applicable to a location of
header(for example,style).
Fields
required: Option<bool>Determines whether this parameter is mandatory. If the parameter location is "path", this property is REQUIRED and its value MUST be true. Otherwise, the property MAY be included and its default value is false.
deprecated: Option<bool>Specifies that a parameter is deprecated and SHOULD be transitioned out of usage. Default value is false.
description: Option<String>A brief description of the parameter. This could contain examples of use. CommonMark syntax MAY be used for rich text representation.
definition: Option<ParameterDefinition>style: Option<ParameterStyle>Describes how the parameter value will be serialized depending on the type of the parameter value. Default values (based on value of in): for query - form; for path - simple; for header - simple; for cookie - form.