Struct apistos_models::paths::MediaType
source · pub struct MediaType {
pub schema: Option<ReferenceOr<Schema>>,
pub example: Option<Examples>,
pub encoding: BTreeMap<String, Encoding>,
pub extensions: IndexMap<String, Value>,
}Expand description
Each Media Type Object provides schema and examples for the media type identified by its key.
Fields
schema: Option<ReferenceOr<Schema>>The schema defining the content of the request, response, or parameter.
example: Option<Examples>encoding: BTreeMap<String, Encoding>extensions: IndexMap<String, Value>This object MAY be extended with Specification Extensions.