Struct apistos_models::paths::PathItem
source · pub struct PathItem {
pub summary: Option<String>,
pub description: Option<String>,
pub operations: IndexMap<OperationType, Operation>,
pub server: Vec<Server>,
pub parameters: Vec<ReferenceOr<Parameter>>,
pub extensions: IndexMap<String, Value>,
}Expand description
Describes the operations available on a single path. A Path Item MAY be empty, due to ACL constraints. The path itself is still exposed to the documentation viewer but they will not know which operations and parameters are available.
Fields
summary: Option<String>An optional, string summary, intended to apply to all operations in this path.
description: Option<String>An optional, string description, intended to apply to all operations in this path. CommonMark syntax MAY be used for rich text representation.
operations: IndexMap<OperationType, Operation>server: Vec<Server>An alternative server array to service all operations in this path.
parameters: Vec<ReferenceOr<Parameter>>A list of parameters that are applicable for all the operations described under this path. These parameters can be overridden at the operation level, but cannot be removed there. The list MUST NOT include duplicated parameters. A unique parameter is defined by a combination of a name and location. The list can use the Reference Object to link to parameters that are defined at the OpenAPI Object’s components/parameters.
extensions: IndexMap<String, Value>This object MAY be extended with Specification Extensions.