Struct apistos_models::paths::Response
source · pub struct Response {
pub description: String,
pub headers: BTreeMap<String, ReferenceOr<Header>>,
pub content: BTreeMap<String, MediaType>,
pub links: BTreeMap<String, ReferenceOr<Link>>,
pub extensions: IndexMap<String, Value>,
}Expand description
Describes a single response from an API Operation, including design-time, static links to operations based on the response.
Fields
description: StringA short description of the response. CommonMark syntax MAY be used for rich text representation.
headers: BTreeMap<String, ReferenceOr<Header>>Maps a header name to its definition. RFC7230 states header names are case insensitive. If a response header is defined with the name "Content-Type", it SHALL be ignored.
content: BTreeMap<String, MediaType>A map containing descriptions of potential response payloads. The key is a media type or media type range and the value describes it. For responses that match multiple keys, only the most specific key is applicable. e.g. text/plain overrides text/*
links: BTreeMap<String, ReferenceOr<Link>>A map of operations links that can be followed from the response. The key of the map is a short name for the link, following the naming constraints of the names for Component Objects.
extensions: IndexMap<String, Value>This object MAY be extended with Specification Extensions.